"""Test cases for not revealjs builders."""
import pytest
from sphinx.testing.util import SphinxTestApp


@pytest.mark.sphinx("html", testroot="default")
def test_for_html_build(app: SphinxTestApp, status, warning):  # noqa
    app.build()


@pytest.mark.sphinx("text", testroot="default")
def test_for_text_build(app: SphinxTestApp, status, warning):  # noqa
    app.build()


@pytest.mark.sphinx("man", testroot="default")
def test_for_man_build(app: SphinxTestApp, status, warning):  # noqa
    app.build()


@pytest.mark.sphinx("texinfo", testroot="default")
def test_for_texinfo_build(app: SphinxTestApp, status, warning):  # noqa
    app.build()


@pytest.mark.sphinx("latex", testroot="default")
def test_for_latex_build(app: SphinxTestApp, status, warning):  # noqa
    app.build()



# -*- coding: utf-8 -*-

# -- Path setup --------------------------------------------------------------
import os
from urllib.parse import urljoin

from sphinx_revealjs.themes import get_theme_path

# -- Project information -----------------------------------------------------
project = "sphinx-revealjs"
copyright = "2018, Kazuya Takei"
author = "Kazuya Takei"
version = ""
release = "2018.10"

# -- General configuration ---------------------------------------------------
extensions = [
    "sphinx.ext.mathjax",
    "sphinx.ext.todo",
    "sphinx_revealjs",
    "sphinx_revealjs.ext.screenshot",
    "sphinxcontrib.budoux",
    "sphinxcontrib.gtagjs",
    "sphinxcontrib.oembed",
    "sphinxcontrib.sass",
    "sphinxext.opengraph",
]
templates_path = ["_templates"]
source_suffix = ".rst"
master_doc = "index"
language = "en"
locale_dirs = ["_locales"]
exclude_patterns = [".venv", "_build", "Thumbs.db", ".DS_Store", "_sections"]
pygments_style = None

# -- Options for HTML output -------------------------------------------------
html_theme = "alabaster"
html_static_path = ["_static"]

# -- Options for Reveal.js output ---------------------------------------------
revealjs_static_path = ["_static"]
revealjs_style_theme = "custom.css"
revealjs_script_conf = {
    "controls": True,
    "progress": True,
    "hash": True,
    "center": True,
    "transition": "slide",
}
revealjs_script_plugins = [
    {
        "name": "RevealNotes",
        "src": "revealjs4/plugin/notes/notes.js",
    },
    {
        "name": "RevealHighlight",
        "src": "revealjs4/plugin/highlight/highlight.js",
    },
    {
        "name": "RevealMath",
        "src": "revealjs4/plugin/math/math.js",
    },
]
revealjs_css_files = [
    "revealjs4/plugin/highlight/zenburn.css",
]
revealjs_notes_from_comments = True

# -- Options for HTMLHelp output ---------------------------------------------
htmlhelp_basename = "sphinx-revealjsdoc"

# -- Options for LaTeX output ------------------------------------------------
latex_elements = {}
latex_documents = [
    (
        master_doc,
        "sphinx-revealjs.tex",
        "sphinx-revealjs Documentation",
        "Kazuya Takei",
        "manual",
    ),
]

# -- Options for manual page output ------------------------------------------
man_pages = [
    (master_doc, "sphinx-revealjs", "sphinx-revealjs Documentation", [author], 1)
]

# -- Options for Texinfo output ----------------------------------------------
texinfo_documents = [
    (
        master_doc,
        "sphinx-revealjs",
        "sphinx-revealjs Documentation",
        author,
        "sphinx-revealjs",
        "One line description of project.",
        "Miscellaneous",
    ),
]

# -- Options for Epub output -------------------------------------------------
epub_title = project
epub_exclude_files = ["search.html"]

# -- Options for extensions --------------------------------------------------
todo_include_todos = True

if "GTAGJS_IDS" in os.environ:
    gtagjs_ids = os.environ["GTAGJS_IDS"].split(",")

budoux_targets = ["h1", "h2", "h3"]

sass_src_dir = "_sass"
sass_out_dir = "_static"
sass_targets = {"custom.scss": "custom.css"}
sass_include_paths = [
    get_theme_path("sphinx_revealjs") / "static" / "revealjs4" / "css" / "theme",
]

# sphinxext-opengraph
ogp_site_url = os.environ.get("DEMO_URL_BASE", "http://localhost:8000/")
ogp_custom_meta_tags = [
    '<meta name="twitter:card" content="summary_large_image" />',
    '<meta name="twitter:site" content="@attakei" />',
]


def update_ogp(app, config):
    print(config.ogp_site_url, config.language)
    config.ogp_site_url = urljoin(config.ogp_site_url, f"{config.language}/")


def setup(app):
    app.connect("config-inited", update_ogp)



"""Configuration for pytest."""
import inspect

import pytest
from _pytest.config import Config
from sphinx import deprecation
from sphinx.testing.path import path

pytest_plugins = "sphinx.testing.fixtures"
collect_ignore = ["roots"]


def pytest_configure(config: Config):  # noqa
    for name, klass in inspect.getmembers(deprecation, inspect.isclass):
        if not issubclass(klass, DeprecationWarning) and not issubclass(
            klass, PendingDeprecationWarning
        ):
            continue
        config.addinivalue_line(
            "filterwarnings", f"error::{klass.__module__}.{klass.__name__}"
        )


@pytest.fixture(scope="session")
def rootdir():
    """Set root directory to use testing sphinx project."""
    return path(__file__).parent.abspath() / "roots"



"""Custom write module."""
from docutils.nodes import Element, SkipNode, comment, literal_block, section
from sphinx.writers.html5 import HTML5Translator

from .nodes import revealjs_break


def has_child_sections(node: Element, name: str):
    """Search has specified section in children."""
    nodes = set([n.tagname for n in node.children])
    return name in nodes


def find_child_section(node: Element, name: str):
    """Search and return first specified section in children."""
    for n in node.children:
        if n.tagname == name:
            return n
    return None


class RevealjsSlideTranslator(HTML5Translator):
    """Translate Reveal.js HTML class."""

    permalink_text = False

    def __init__(self, builder, *args, **kwds):  # noqa: D107
        super().__init__(builder, *args, **kwds)
        self.builder.add_permalinks = False
        self._proc_first_on_section = False

    def visit_section(self, node: section):
        """Begin ``section`` node.

        - Find first ``revealjs_section`` node and build attributes string.
        - When enter next section, nest level.
        """
        self.section_level += 1
        meta = find_child_section(node, "revealjs_section")
        if meta is not None:
            attrs = meta.attributes_str()
        else:
            attrs = ""
        if node.attributes.get("ids") and self.config.revealjs_use_section_ids:
            attrs += ' id="{}"'.format(node.attributes["ids"][-1])
        if self.section_level == 1:
            self.builder.revealjs_slide = find_child_section(node, "revealjs_slide")
            self._proc_first_on_section = True
            self.body.append(f"<section {attrs}>\n")
            return
        if self._proc_first_on_section:
            self._proc_first_on_section = False
            self.body.append("</section>\n")

        if has_child_sections(node, "section"):
            self._proc_first_on_section = True
            self.body.append("<section>\n")
        self.body.append(f"<section {attrs}>\n")

    def depart_section(self, node: section):
        """End ``section``.

        Dedent section level
        """
        self.section_level -= 1
        if self.section_level >= 1:
            self.body.append("</section>\n")

    def visit_comment(self, node: comment):
        """Begin ``comment`` node.

        comment node render as speaker note.
        """
        if self.builder.app.config.revealjs_notes_from_comments:
            self.body.append('<aside class="notes">\n')
        else:
            raise SkipNode

    def depart_comment(self, node: comment):
        """End ``comment`` node.

        Close speaker note.
        """
        if self.builder.app.config.revealjs_notes_from_comments:
            self.body.append("</aside>\n")

    def visit_literal_block(self, node: literal_block):
        """Begin ``literal_block`` .

        Override base method, and open simply ``pre`` and ``code`` tags.
        """
        lang = node["language"]
        # add section id as data-id if it is exists
        if "data-id" in node:
            self.body.append(f"<pre data-id=\"{node['data-id']}\">")
        elif isinstance(node.parent, section) and len(node.parent["ids"]):
            self.body.append(f"<pre data-id=\"{node.parent['ids'][0]}\">")
        else:
            self.body.append("<pre>")
        self.body.append(f'<code data-trim data-noescape class="{lang}"')
        # use the emphasize-lines directive to create line for line animations
        if "data-line-numbers" in node:
            self.body.append(f" data-line-numbers=\"{node['data-line-numbers']}\"")
        else:
            # show line numbers
            if node["linenos"]:
                self.body.append(" data-line-numbers")
        if "data-ln-start-from" in node:
            self.body.append(f" data-ln-start-from=\"{node['data-ln-start-from']}\"")
            if "data-line-numbers" not in node:
                self.body.append(" data-line-numbers")
        self.body.append(">")

    def depart_literal_block(self, node: literal_block):
        """End ``literal_block``.

        Override base method, and close begun tags.
        """
        self.body.append("</code></pre>\n")


def not_write(self, node):
    """visit/depart function for declare "no write"."""
    pass


def visit_revealjs_break(self, node: revealjs_break):
    """Close current section."""
    self.body.append("</section>\n")


def depart_revealjs_break(self, node: revealjs_break):
    """Open as next section.

    If node does not have attribute 'notitle',
    render title from current original section.
    """
    attrs = node.attributes_str()
    self.body.append(f"<section {attrs}>\n")
    if "notitle" not in node.attributes:
        title = find_child_section(node.parent, "title")
        self.body.append(f"<h{self.section_level}>")
        self.body.append(title.children[0])
        self.body.append(f"</h{self.section_level}>")
        self.body.append("\n")



"""Test cases for generating giles."""
import pytest
from sphinx.testing.util import SphinxTestApp


@pytest.mark.sphinx(
    "revealjs", testroot="default", confoverrides={"revealjs_use_index": True}
)
def test_generating_genindex(app: SphinxTestApp, status, warning):  # noqa
    app.build()
    assert (app.outdir / "genindex.html").exists()



"""Build tests for configuration parameters."""
import pytest
from sphinx.testing.util import SphinxTestApp
from testutils import soup_html


class TestForRevealjsScriptFiles:  # noqa
    @pytest.mark.sphinx(
        "revealjs",
        testroot="for-config",
        freshenv=True,
        confoverrides={"revealjs_script_files": ["js/test.js"]},
    )
    def test_adding_localfile(self, app: SphinxTestApp, status, warning):  # noqa
        soup = soup_html(app, "index.html")
        elements = [
            e for e in soup.find_all("script") if e.get("src") == "_static/js/test.js"
        ]
        assert len(elements) == 1

    @pytest.mark.sphinx(
        "revealjs",
        testroot="for-config",
        freshenv=True,
        confoverrides={"revealjs_script_files": ["https://example.com/test.js"]},
    )
    def test_adding_url(self, app: SphinxTestApp, status, warning):  # noqa
        soup = soup_html(app, "index.html")
        elements = [
            e
            for e in soup.find_all("script")
            if e.get("src") == "https://example.com/test.js"
        ]
        assert len(elements) == 1


class TestForRevealjsScriptConfig:  # noqa
    @pytest.mark.sphinx(
        "revealjs",
        testroot="for-config",
        confoverrides={"revealjs_script_conf": '{transition:"none"}'},
    )
    def test_using_as_text(self, app: SphinxTestApp, status, warning):  # noqa
        soup = soup_html(app, "index.html")
        assert 'Object.assign(revealjsConfig, {transition:"none"});' in str(
            soup.find_all("script")[-1]
        )

    @pytest.mark.sphinx(
        "revealjs",
        testroot="for-config",
        confoverrides={"revealjs_script_conf": {"transition": "none"}},
    )
    def test_using_as_dict(self, app: SphinxTestApp, status, warning):  # noqa
        soup = soup_html(app, "index.html")
        assert (
            'Object.assign(revealjsConfig, JSON.parse(\'{"transition": "none"}\'));'
            in str(soup.find_all("script")[-1])
        )


@pytest.mark.sphinx(
    "revealjs",
    testroot="for-config",
    confoverrides={
        "revealjs_script_plugins": [
            {
                "name": "RevealNotes",
                "src": "revealjs4/plugin/notes/notes.js",
            }
        ]
    },
)
def test_revealjs_script_plugins(app: SphinxTestApp, status, warning):  # noqa
    soup = soup_html(app, "index.html")
    script = str(soup.find_all("script")[-1])
    assert "RevealNotes" in script
    for d in soup.find_all("script"):
        print(d)
    scripts = [d["src"] for d in soup.find_all("script") if "src" in d.attrs]
    assert "_static/revealjs4/plugin/notes/notes.js" in scripts
    assert "RevealNotes" in str(soup)



"""Extension to generate screenshot for first page of presentation.

This is optional extension.
You need install extra and configure to use it.
"""
from pathlib import Path
from typing import Dict, Set

from sphinx.application import Sphinx
from sphinx.environment import BuildEnvironment
from sphinx.errors import ExtensionError
from sphinx.util.logging import getLogger
from sphinx.util.matching import Matcher

from ..builders import RevealjsHTMLBuilder

try:
    from playwright.sync_api import sync_playwright
except ImportError:
    msg = (
        f"{__name__} need playwright."
        "you should run \"pip install 'sphinx-revealjs[screenshot]'\"."
    )
    raise ExtensionError(msg)

from .. import __version__ as core_version

logger = getLogger(__name__)
_targets: Dict[str, str] = dict()


def collect_screenshot_targets(
    app: Sphinx,
    env: BuildEnvironment,
    added: Set[str],
    changed: Set[str],
    removed: Set[str],
):
    global _targets
    _targets = {}
    for docname in added:
        _targets[docname] = f"{app.config.revealjs_screenshot_outdir}/{docname}.png"
    for docname in changed:
        _targets[docname] = f"{app.config.revealjs_screenshot_outdir}/{docname}.png"
    return []


def generate_screenshots(app: Sphinx, exception: Exception):
    logger.info("Generating screenshot")
    with sync_playwright() as p:
        browser = p.chromium.launch()
        page = browser.new_page()
        matcher = Matcher(app.config.revealjs_screenshot_excludes)
        for docname, image_url in _targets.items():
            if matcher(docname):
                continue
            page_path = Path(app.outdir) / app.builder.get_target_uri(docname)
            if page_path.is_dir():
                page_path = page_path / "index.html"
            image_path = Path(app.outdir) / image_url
            page.goto(f"file://{page_path}")
            conf = page.evaluate("Reveal.getConfig()")
            page.set_viewport_size({"width": conf["width"], "height": conf["height"]})
            page.screenshot(path=image_path)


def connect_extension_events(app: Sphinx):
    if isinstance(app.builder, RevealjsHTMLBuilder):
        app.connect("env-get-outdated", collect_screenshot_targets)
        app.connect("build-finished", generate_screenshots)


def setup(app: Sphinx):
    """Entryoint."""
    app.add_config_value("revealjs_screenshot_outdir", "_images/ogp", "env")
    app.add_config_value("revealjs_screenshot_excludes", [], "env")
    app.connect("builder-inited", connect_extension_events)
    return {
        "version": core_version,
        "env_version": 1,
        "parallel_read_safe": True,
    }



"""Build tests for configuration parameters."""
import pytest
from sphinx.testing.util import SphinxTestApp
from testutils import soup_html


@pytest.mark.sphinx(
    "revealjs",
    testroot="for-config",
    confoverrides={
        "revealjs_static_path": ["_static"],
        "revealjs_css_files": ["custom.css"],
    },
)
def test_default_theme_css_comes_before_custom_css(
    app: SphinxTestApp, status, warning
):  # noqa
    soup = soup_html(app, "index.html")
    stylesheet_href_list = [e["href"] for e in soup.find_all("link", rel="stylesheet")]
    default_theme_index = stylesheet_href_list.index(
        "_static/revealjs4/dist/theme/black.css"
    )
    custom_css_index = stylesheet_href_list.index("_static/custom.css")
    assert default_theme_index < custom_css_index


@pytest.mark.sphinx(
    "revealjs",
    testroot="for-config",
    confoverrides={
        "revealjs_style_theme": "moon",
        "revealjs_static_path": ["_static"],
        "revealjs_css_files": ["other_custom.css"],
    },
)
def test_specified_theme_css_comes_before_custom_css(
    app: SphinxTestApp, status, warning
):  # noqa
    soup = soup_html(app, "index.html")
    stylesheet_href_list = [e["href"] for e in soup.find_all("link", rel="stylesheet")]
    specified_theme_index = stylesheet_href_list.index(
        "_static/revealjs4/dist/theme/moon.css"
    )
    custom_css_index = stylesheet_href_list.index("_static/other_custom.css")
    assert specified_theme_index < custom_css_index



"""Internal extension for highlighting of Reveal.js."""
from docutils.parsers.rst import directives
from sphinx.application import Sphinx
from sphinx.directives.code import CodeBlock, LiteralInclude

from .. import __version__


class RevealjsCodeBlock(CodeBlock):  # noqa: D101
    option_spec = {
        **CodeBlock.option_spec,
        "data-id": directives.unchanged,
        "data-line-numbers": directives.unchanged,
        "data-ln-start-from": directives.unchanged,
    }

    def run(self):  # noqa: D102
        nodes = super().run()
        if self.options.get("data-line-numbers"):
            nodes[0]["data-line-numbers"] = self.options.get("data-line-numbers")
        if self.options.get("data-id"):
            nodes[0]["data-id"] = self.options.get("data-id")
        if self.options.get("data-ln-start-from"):
            nodes[0]["data-ln-start-from"] = self.options.get("data-ln-start-from")
        return nodes


class RevealjsLiteralInclude(LiteralInclude):
    """Extends from ``literalinclude`` directive.

    This has ``data-line-numbers`` for step-by-step code highlighting.
    See `it <https://revealjs.com/code/>`_ for more information.
    """

    option_spec = {
        **LiteralInclude.option_spec,
        "data-id": directives.unchanged,
        "data-line-numbers": directives.unchanged,
        "data-ln-start-from": directives.unchanged,
    }

    def run(self):  # noqa: D102
        nodes = super().run()
        if self.options.get("data-line-numbers"):
            nodes[0]["data-line-numbers"] = self.options.get("data-line-numbers")
        if self.options.get("data-id"):
            nodes[0]["data-id"] = self.options.get("data-id")
        if self.options.get("data-ln-start-from"):
            nodes[0]["data-ln-start-from"] = self.options.get("data-ln-start-from")
        return nodes


def setup(app: Sphinx):  # noqa: D103
    app.add_directive("revealjs-code-block", RevealjsCodeBlock)
    app.add_directive("revealjs-literalinclude", RevealjsLiteralInclude)
    return {
        "version": __version__,
        "env_version": 2,
        "parallel_read_safe": True,
    }



"""Internal extension for Speaker view or Reveal.js."""
import html

from docutils import nodes
from docutils.parsers.rst.directives.admonitions import BaseAdmonition
from sphinx.application import Sphinx
from sphinx.directives import SphinxDirective
from sphinx.util.docutils import SphinxTranslator

from .. import __version__
from ..builders import RevealjsHTMLBuilder
from ..writers import not_write


class revealjs_notes(nodes.Admonition, nodes.Element):  # noqa: D101
    pass


class RevealjsNotes(BaseAdmonition, SphinxDirective):  # noqa: D101
    has_content = True
    node_class = revealjs_notes

    def run(self):  # noqa: D102
        (node,) = super().run()
        if isinstance(node, (nodes.system_message, revealjs_notes)):
            return [node]


def visit_revealjs_notes(self: SphinxTranslator, node: revealjs_notes):  # noqa: D103
    if not isinstance(self.builder, RevealjsHTMLBuilder):
        self.visit_admonition(node)
        return
    self.body.append(f'<aside class="notes">{html.escape(node.astext())}</aside>')
    raise nodes.SkipNode


def depart_revaljs_notes(self: SphinxTranslator, node: revealjs_notes):  # noqa: D103
    if not isinstance(self.builder, RevealjsHTMLBuilder):
        self.depart_admonition(node)
        return


def setup(app: Sphinx):  # noqa: D103
    app.add_node(
        revealjs_notes,
        html=(visit_revealjs_notes, depart_revaljs_notes),
        latex=(not_write, not_write),
        text=(not_write, not_write),
        man=(not_write, not_write),
        texinfo=(not_write, not_write),
        revealjs=(visit_revealjs_notes, depart_revaljs_notes),
        dirrevealjs=(visit_revealjs_notes, depart_revaljs_notes),
    )
    app.add_directive("revealjs-notes", RevealjsNotes)
    app.add_config_value("revealjs_notes_from_comments", False, "env")
    return {
        "version": __version__,
        "env_version": 2,
        "parallel_read_safe": True,
    }



"""Test cases for sphix_revealjs.ext.screenshot."""
import magic
import pytest
from PIL import Image
from sphinx.testing.util import SphinxTestApp


@pytest.mark.sphinx(
    "revealjs",
    testroot="default",
    freshenv=True,
    confoverrides={"extensions": ["sphinx_revealjs", "sphinx_revealjs.ext.screenshot"]},
)
def test_generate_screenshot(app: SphinxTestApp, status, warning):  # noqa
    app.build()
    image_path = app.outdir / "_images/ogp/index.png"
    assert image_path.exists()
    assert magic.from_file(image_path, mime=True) == "image/png"
    with Image.open(image_path) as img:
        width, height = img.size
        assert width == 960
        assert height == 700


@pytest.mark.sphinx(
    "revealjs",
    testroot="includes",
    confoverrides={
        "extensions": ["sphinx_revealjs", "sphinx_revealjs.ext.screenshot"],
        "revealjs_screenshot_excludes": ["content"],
    },
)
def test_skip_included(app: SphinxTestApp, status, warning):  # noqa
    app.build()
    image_path = app.outdir / "_images/ogp/content.png"
    assert not image_path.exists()


@pytest.mark.sphinx(
    "dirrevealjs",
    testroot="default",
    freshenv=True,
    confoverrides={
        "extensions": ["sphinx_revealjs", "sphinx_revealjs.ext.screenshot"],
    },
)
def test_dirrevealjs(app: SphinxTestApp, status, warning):  # noqa
    app.build()


@pytest.mark.sphinx(
    "revealjs",
    testroot="viewports",
)
def test_customize_size_by_directive(app: SphinxTestApp, status, warning):  # noqa
    app.build()
    with Image.open(app.outdir / "_images/ogp/index.png") as img:
        width, height = img.size
        assert width == 960
        assert height == 700
    with Image.open(app.outdir / "_images/ogp/custom.png") as img:
        width, height = img.size
        assert width == 1280
        assert height == 720


@pytest.mark.sphinx(
    "revealjs",
    testroot="viewports",
    confoverrides={"revealjs_script_conf": {"width": 960, "height": 720}},
)
def test_customize_size_by_conf(app: SphinxTestApp, status, warning):  # noqa
    app.build()
    with Image.open(app.outdir / "_images/ogp/index.png") as img:
        width, height = img.size
        assert width == 960
        assert height == 720
    with Image.open(app.outdir / "_images/ogp/custom.png") as img:
        width, height = img.size
        assert width == 1280
        assert height == 720


@pytest.mark.sphinx(
    "html",
    testroot="viewports",
)
def test_work_in_html_builder(app: SphinxTestApp, status, warning):  # noqa
    app.build()
    image_path = app.outdir / "_images/ogp/index.png"
    assert not image_path.exists()



# -*- coding: utf-8 -*-
from pathlib import Path

from sphinx_revealjs import __version__

PROJ_ROOT = Path(__file__).parents[1]

# -- Project information -----------------------------------------------------
project = "sphinx-revealjs"
copyright = "2018, Kazuya Takei"
author = "Kazuya Takei"
version = __version__
release = __version__

# -- General configuration ---------------------------------------------------
extensions = [
    "sphinx.ext.intersphinx",
    "sphinx.ext.todo",
]
templates_path = ["_templates"]
source_suffix = ".rst"
master_doc = "index"
language = "en"
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
pygments_style = None
rst_prolog = """
.. |THIS| replace:: ``sphinx-revealjs``
"""

# -- Options for HTML output -------------------------------------------------
html_theme = "sphinx_rtd_theme"
html_static_path = ["_static"]
html_css_files = ["custom.css"]

# -- Options for HTMLHelp output ---------------------------------------------
htmlhelp_basename = "sphinx-revealjsdoc"

# -- Options for LaTeX output ------------------------------------------------
latex_elements = {}
latex_documents = [
    (
        master_doc,
        "sphinx-revealjs.tex",
        "sphinx-revealjs Documentation",
        "Kazuya Takei",
        "manual",
    ),
]

# -- Options for manual page output ------------------------------------------
man_pages = [
    (master_doc, "sphinx-revealjs", "sphinx-revealjs Documentation", [author], 1)
]

# -- Options for Texinfo output ----------------------------------------------
texinfo_documents = [
    (
        master_doc,
        "sphinx-revealjs",
        "sphinx-revealjs Documentation",
        author,
        "sphinx-revealjs",
        "One line description of project.",
        "Miscellaneous",
    ),
]

# -- Options for Epub output -------------------------------------------------
epub_title = project
epub_exclude_files = ["search.html"]

# -- Extension configuration -------------------------------------------------
# For sphinx.ext.intersphinx
intersphinx_mapping = {
    "sphinx": ("https://www.sphinx-doc.org/en/master", None),
}
# For sphinx.ext.todo
todo_include_todos = True


def setup(app):
    app.add_object_type(
        "confval",
        "confval",
        objname="configuration value",
        indextemplate="pair: %s; configuration value",
    )



"""Test cases for deprecated messages from Sphinx."""
import sys

import pytest
from sphinx.testing.util import SphinxTestApp


@pytest.mark.sphinx("revealjs", testroot="default")
@pytest.mark.skipif(
    sys.version_info.major == 3 and sys.version_info.minor >= 7,
    reason="Run only deprecated python version",
)
def test_not_notice(app: SphinxTestApp, status, warning, capsys):  # noqa
    app.build()
    # Left is return warning text if exists.
    assert warning.getvalue() != ""



#!/usr/bin/env python
"""Bump post version writer."""
import argparse
import configparser
from datetime import datetime
from pathlib import Path

parser = argparse.ArgumentParser()
parser.add_argument("release_type", choices=["post", "dev"], default="post")


def calc_pre(release_type: str) -> str:
    """Generate post version number from timestamp."""
    cur = datetime.now()
    return f"{release_type}{int(cur.timestamp())}"


def bump_file(fpath: Path, current_version: str, next_version: str):
    """Change version string not using bump2version."""
    with fpath.open() as fp:
        raw = fp.read()
    with fpath.open("w") as fp:
        fp.write(raw.replace(current_version, next_version))


def main(args):  # noqa
    setup_cfg = configparser.ConfigParser()
    setup_cfg.read("setup.cfg")
    current_version = setup_cfg.get("bumpversion", "current_version")
    next_version = f"{current_version}.{calc_pre(args.release_type)}"
    # Find bump files and bumpversion
    for sec in setup_cfg.sections():
        if not sec.startswith("bumpversion:file:"):
            continue
        bump_file(Path(sec[17:]), current_version, next_version)


if __name__ == "__main__":
    args = parser.parse_args()
    main(args)



#!/usr/bin/env python
import argparse
from pathlib import Path

from jinja2 import Template

here = Path(__file__).parent

parser = argparse.ArgumentParser()
parser.add_argument("outdir", type=Path)


def main(args: argparse.Namespace):
    languages = ["en"] + [v.name for v in (here / "_locales").glob("*")]
    for tmpl_path in here.glob("*.html.j2"):
        tmpl = Template(tmpl_path.read_text())
        out_path: Path = args.outdir / tmpl_path.stem
        out_path.write_text(tmpl.render(languages=languages))


if __name__ == "__main__":
    args = parser.parse_args()
    main(args)
